<?php
// $Id: views-more.tpl.php,v 1.3 2009/06/02 20:35:52 merlinofchaos Exp $
/**
 * @file views-more.tpl.php
 * Theme the more link
 *
 * - $more_url: the url for the more link
 *
 * @ingroup views_templates
 */
?>

<div class="more-link">
  <a href="<?php print $more_url ?>">
    <?php print $link_text; ?>
  </a>
</div>
